@@ -306,7 +306,7 @@ mod tests {
         }
 
         fn get_signature(&self, name: &str) -> Option<nu_protocol::Signature> {
-            self.0.iter().find(|v| v.name == name).map(Clone::clone)
+            self.0.iter().find(|v| v.name == name).cloned()
         }
 
         fn get_alias(&self, _name: &str) -> Option<Vec<Spanned<String>>> {
@@ -317,6 +317,10 @@ mod tests {
             todo!()
         }
 
+        fn remove_alias(&self, _name: &str) {
+            todo!()
+        }
+
         fn add_definition(&self, _block: Arc<Block>) {}
 
         fn get_definitions(&self) -> Vec<Arc<Block>> {
@@ -352,7 +356,8 @@ mod tests {
         #[test]
         fn completes_internal_command_names() {
             let registry: VecRegistry =
-                vec![Signature::build("echo").rest(SyntaxShape::Any, "the values to echo")].into();
+                vec![Signature::build("echo").rest("rest", SyntaxShape::Any, "the values to echo")]
+                    .into();
             let line = "echo 1 | echo 2";
 
             assert_eq!(
@@ -398,7 +403,7 @@ mod tests {
         fn completes_flags() {
             let registry: VecRegistry = vec![Signature::build("du")
                 .switch("recursive", "the values to echo", None)
-                .rest(SyntaxShape::Any, "blah")]
+                .rest("rest", SyntaxShape::Any, "blah")]
             .into();
 
             let line = "du --recurs";
@@ -438,7 +443,7 @@ mod tests {
         fn completes_flags_with_just_a_single_hyphen() {
             let registry: VecRegistry = vec![Signature::build("du")
                 .switch("recursive", "the values to echo", None)
-                .rest(SyntaxShape::Any, "blah")]
+                .rest("rest", SyntaxShape::Any, "blah")]
             .into();
 
             let line = "du -";
@@ -455,7 +460,8 @@ mod tests {
         #[test]
         fn completes_arguments() {
             let registry: VecRegistry =
-                vec![Signature::build("echo").rest(SyntaxShape::Any, "the values to echo")].into();
+                vec![Signature::build("echo").rest("rest", SyntaxShape::Any, "the values to echo")]
+                    .into();
             let line = "echo 1 | echo 2";
 
             assert_eq!(
